@@ -9,7 +9,7 @@ use warnings;
 use strict;
 use Carp;
 use base 'DBIx::DataModel::Base';
-use SQL::Abstract;
+use SQL::Abstract 1.50;
 use DBIx::DataModel::Table;
 use DBIx::DataModel::View;
 use POSIX        (); # INT_MAX
@@ -192,7 +192,7 @@ sub View {
   if ($FROM_THAW) {
     # Storable::thaw already created the package; just add @ISA to it
     no strict 'refs';
-    *{$view."::ISA"} = $isa;
+    @{$view."::ISA"} = @$isa;
   }
   else {
     # normal case: create a new package
@@ -501,7 +501,17 @@ sub join {
   $class->View(@view_args);
 
   # add alias information
-  $viewName->classData->{tableAliases} = \%aliases;
+
+
+  # in Perl5.10, when reaching here while called from "require",
+  # called itself from "STORABLE_thaw", then the method cache is 
+  # not yet available. So we replace the method call by a direct
+  # functional call to the method implementation
+  # COMMENTED : 
+
+$viewName->classData->{tableAliases} = \%aliases;
+
+##  DBIx::DataModel::Base::classData($viewName)->{tableAliases} = \%aliases;
 
   return $viewName;
 }
@@ -703,13 +713,12 @@ sub doTransaction {
     };
 
     # if any error, rollback
-    my $errstr = $@;
-    if ($errstr) {              # the transaction failed
+    my $err = $@;
+    if ($err) {              # the transaction failed
       my @rollback_errs = grep {$_} map {eval{$_->rollback}; $@} 
                                         reverse @$transaction_dbhs;
-      my $status = @rollback_errs ? CORE::join(", ", @rollback_errs) : "OK";
       delete $classData->{transaction_dbhs};
-      croak "FAILED TRANSACTION: $errstr (rollback: $status)";
+      DBIx::DataModel::Schema::_Exception->throw($err, @rollback_errs);
     }
   }
 
@@ -717,6 +726,7 @@ sub doTransaction {
 }
 
 
+
 sub keepLasth {
   my $class = shift;
 
@@ -745,8 +755,6 @@ sub unbless {
 
 
 
-
-
 #----------------------------------------------------------------------
 # UTILITY METHODS (PRIVATE)
 #----------------------------------------------------------------------
@@ -756,8 +764,8 @@ sub _createPackage {
   my ($schema, $pckName, $isa_arrayref) = @_;
   no strict 'refs';
 
-  not defined(%{$pckName.'::'}) or croak "package $pckName is already defined";
-  *{$pckName."::ISA"} = $isa_arrayref;
+  !(%{$pckName.'::'}) or croak "package $pckName is already defined";
+  @{$pckName."::ISA"} = @$isa_arrayref;
   return $pckName;
 }
 
@@ -785,8 +793,8 @@ sub _defineMethod {
 sub _ensureClassLoaded {
   my ($schema, $to_load) = @_;
   no strict 'refs';
-  defined(%{$to_load.'::'}) or eval "require $to_load" 
-                            or croak "can't load class $to_load : $@";
+  (%{$to_load.'::'}) or eval "require $to_load" 
+                     or croak "can't load class $to_load : $@";
 }
 
 #----------------------------------------------------------------------
@@ -868,7 +876,7 @@ sub _unbless {
 
 
 #----------------------------------------------------------------------
-# INTERNAL CLASS FOR LOCALIZING STATE (see L</localizeState> method
+# PRIVATE CLASS FOR LOCALIZING STATE (see L</localizeState> method
 #----------------------------------------------------------------------
 
 package DBIx::DataModel::Schema::_State;
@@ -887,6 +895,40 @@ sub DESTROY { # called when the guard goes out of scope
 }
 
 
+#----------------------------------------------------------------------
+# PRIVATE CLASS FOR TRANSACTION EXCEPTIONS
+#----------------------------------------------------------------------
+
+package DBIx::DataModel::Schema::_Exception;
+use strict;
+use warnings;
+
+use overload '""' => sub {
+  my $self = shift;
+  my $err             = $self->initial_error;
+  my @rollback_errs   = $self->rollback_errors;
+  my $rollback_status = @rollback_errs ? join(", ", @rollback_errs) : "OK";
+  return "FAILED TRANSACTION: $err (rollback: $rollback_status)";
+};
+
+
+sub throw {
+  my $class = shift;
+  my $self = bless [@_], $class;
+  die $self;
+}
+
+sub initial_error {
+  my $self = shift;
+  return $self->[0];
+}
+
+sub rollback_errors {
+  my $self = shift;
+  return @$self[1..$#{@$self}];
+}
+
+
 1; 
 
 __END__
@@ -951,6 +993,19 @@ This module implements
 
 =back
 
+=head1 PRIVATE SUBCLASSES
+
+This module has two internal subclasses.
+
+=head2 _State
+
+A private class for localizing state (using a DESTROY method).
+
+=head2 _Exception
+
+A private class for exceptions during transactions
+(see  L<doTransaction|DBIx::DataModel::Doc::Reference/doTransaction>).
+
 
 
 =head1 AUTHOR
