@@ -372,12 +372,12 @@ sub select {
       return $self->sql;
     };
 
-    # CASE subquery : just return the SQL and bind values
+    # CASE subquery : return a ref to an arrayref with SQL and bind values
     /^subquery$/i        and do {
       not $callbacks 
         or croak "$callbacks incompatible with -resultAs=>'subquery'";
       my ($sql, @bind) = $self->sql;
-      return [\"($sql)", @bind];
+      return \ ["($sql)", @bind];
     };
 
     # for all other cases, must first execute the statement
@@ -513,9 +513,9 @@ sub all {
 }
 
 
-sub pageSize       {shift->{args}{-pageSize} || INT_MAX}
-sub pageIndex      {shift->{pageIndex}       || 1      }
-sub offset         {shift->{offset}          || 0      }
+sub pageSize       {shift->{args}{-pageSize}  || INT_MAX}
+sub pageIndex      {shift->{args}{-pageIndex} || 1      }
+sub offset         {shift->{offset}           || 0      }
 
 
 sub pageCount {
@@ -724,18 +724,13 @@ sub _reorganize_pagination {
     not exists $args->{$_} or croak "conflicting parameters: -pageSize and $_"
       for qw/-limit -offset/;
     $args->{-limit} = $args->{-pageSize};
-    $self->_set_pageIndex($args->{-pageIndex}) if $args->{-pageIndex};
-
+    if ($args->{-pageIndex}) {
+      $args->{-offset} = ($args->{-pageIndex} - 1) * $args->{-pageSize};
+    }
   }
 }
 
 
-sub _set_pageIndex {
-  my ($self, $pageIndex) = @_;
-
-}
-
-
 sub _limit_offset {
   my ($self, $sql_ref, $bind_ref) = @_;
 
@@ -763,8 +758,7 @@ sub _add_conditions { # merge conditions for L<SQL::Abstract/where>
       }
     }
     elsif (isa $cond, 'ARRAY') {
-      $merged{-nest} = $merged{-nest} ? [-and => [-nest => $merged{-nest}, 
-                                                  -nest => $cond]]
+      $merged{-nest} = $merged{-nest} ? [-and => $merged{-nest}, $cond]
                                       : $cond;
     }
     elsif ($cond) {
@@ -1133,8 +1127,6 @@ redefined in subclasses :
 
 =item _resolve_source
 
-=item _set_pageIndex
-
 =item _limit_offset
 
 =item _add_conditions
