@@ -132,7 +132,7 @@ sub fetch {
     %select_args = %{pop @_};
   }
 
-  return $class->select(-fetch => @_, %select_args);
+  return $class->select(-fetch => \@_, %select_args);
 }
 
 
@@ -257,6 +257,7 @@ sub _insert_subtrees {
     while (my ($role, $arrayref) = each %$subrecords) { # insert_into each role
       UNIVERSAL::isa($arrayref, 'ARRAY')
           or croak "Expected an arrayref for component role $role in $class";
+      next if not @$arrayref;
       my $meth = "insert_into_$role";
       $self->$meth(@$arrayref);
       $self->{$role} = $arrayref;
